==> snap-rcp-3.0.2-20160504.124053-9-sources.jar: org/esa/snap/rcp/preferences/general/Bundle.java <==
package org.esa.snap.rcp.preferences.general;
/** Localizable strings for {@link org.esa.snap.rcp.preferences.general}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>UI Behaviour</i>
     * @see UiBehaviorController
     */
    static String AdvancedOption_DisplayName_UiBehavior() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "AdvancedOption_DisplayName_UiBehavior");
    }
    /**
     * @return <i>UI, behavior</i>
     * @see UiBehaviorController
     */
    static String AdvancedOption_Keywords_UiBehavior() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "AdvancedOption_Keywords_UiBehavior");
    }
    /**
     * @return <i>general</i>
     * @see package-info
     */
    static String OptionsCategory_Keywords_Category_General() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "OptionsCategory_Keywords_Category_General");
    }
    /**
     * @return <i>general</i>
     * @see package-info
     */
    static String OptionsCategory_Keywords_General() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "OptionsCategory_Keywords_General");
    }
    /**
     * @return <i>General</i>
     * @see package-info
     */
    static String OptionsCategory_Name_General() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "OptionsCategory_Name_General");
    }
    /**
     * @return <i>Image View</i>
     * @see ImageViewController
     */
    static String Options_DisplayName_LayerGeneral() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_LayerGeneral");
    }
    /**
     * @return <i>New Masks</i>
     * @see MaskLayerController
     */
    static String Options_DisplayName_LayerMask() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_LayerMask");
    }
    /**
     * @return <i>Quicklooks</i>
     * @see QuicklookOptionsController
     */
    static String Options_DisplayName_QuicklookOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_QuicklookOptions");
    }
    /**
     * @return <i>RGB-Image Profiles</i>
     * @see RgbController
     */
    static String Options_DisplayName_RGB() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_RGB");
    }
    /**
     * @return <i>Write Options</i>
     * @see WriteOptionsController
     */
    static String Options_DisplayName_WriteOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_WriteOptions");
    }
    /**
     * @return <i>layer, general</i>
     * @see ImageViewController
     */
    static String Options_Keywords_LayerGeneral() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_LayerGeneral");
    }
    /**
     * @return <i>layer, mask</i>
     * @see MaskLayerController
     */
    static String Options_Keywords_LayerMask() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_LayerMask");
    }
    /**
     * @return <i>Quicklook</i>
     * @see QuicklookOptionsController
     */
    static String Options_Keywords_QuicklookOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_QuicklookOptions");
    }
    /**
     * @return <i>RGB, profile</i>
     * @see RgbController
     */
    static String Options_Keywords_RGB() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_RGB");
    }
    /**
     * @return <i>write, writing, save, header, MPH, SPH, history, annotation, incremental</i>
     * @see WriteOptionsController
     */
    static String Options_Keywords_WriteOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_WriteOptions");
    }
    /**
     * @return <i>Geo-Location</i>
     * @see GeoLocationController
     */
    static String TXT_GeoLocationController_DisplayName() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "TXT_GeoLocationController_DisplayName");
    }
    /**
     * @return <i>geo, location, geo-location, compatibility, differ</i>
     * @see GeoLocationController
     */
    static String TXT_GeoLocationController_Keyword() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "TXT_GeoLocationController_Keyword");
    }
    private void Bundle() {}
}

==> snap-rcp-5.0.8-20170727.054422-18-sources.jar: org/esa/snap/rcp/preferences/general/Bundle.java <==
package org.esa.snap.rcp.preferences.general;
/** Localizable strings for {@link org.esa.snap.rcp.preferences.general}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>Other</i>
     * @see OtherOptionsController
     */
    static String AdvancedOption_DisplayName_Other() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "AdvancedOption_DisplayName_Other");
    }
    /**
     * @return <i>UI Behaviour</i>
     * @see UiBehaviorController
     */
    static String AdvancedOption_DisplayName_UiBehavior() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "AdvancedOption_DisplayName_UiBehavior");
    }
    /**
     * @return <i>other</i>
     * @see OtherOptionsController
     */
    static String AdvancedOption_Keywords_Other() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "AdvancedOption_Keywords_Other");
    }
    /**
     * @return <i>UI, behavior</i>
     * @see UiBehaviorController
     */
    static String AdvancedOption_Keywords_UiBehavior() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "AdvancedOption_Keywords_UiBehavior");
    }
    /**
     * @return <i>general</i>
     * @see package-info
     */
    static String OptionsCategory_Keywords_Category_General() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "OptionsCategory_Keywords_Category_General");
    }
    /**
     * @return <i>general</i>
     * @see package-info
     */
    static String OptionsCategory_Keywords_General() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "OptionsCategory_Keywords_General");
    }
    /**
     * @return <i>General</i>
     * @see package-info
     */
    static String OptionsCategory_Name_General() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "OptionsCategory_Name_General");
    }
    /**
     * @return <i>Image View</i>
     * @see ImageViewController
     */
    static String Options_DisplayName_LayerGeneral() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_LayerGeneral");
    }
    /**
     * @return <i>New Masks</i>
     * @see MaskLayerController
     */
    static String Options_DisplayName_LayerMask() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_LayerMask");
    }
    /**
     * @return <i>Quicklooks</i>
     * @see QuicklookOptionsController
     */
    static String Options_DisplayName_QuicklookOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_QuicklookOptions");
    }
    /**
     * @return <i>RGB-Image Profiles</i>
     * @see RgbController
     */
    static String Options_DisplayName_RGB() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_RGB");
    }
    /**
     * @return <i>Write Options</i>
     * @see WriteOptionsController
     */
    static String Options_DisplayName_WriteOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_DisplayName_WriteOptions");
    }
    /**
     * @return <i>layer, general</i>
     * @see ImageViewController
     */
    static String Options_Keywords_LayerGeneral() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_LayerGeneral");
    }
    /**
     * @return <i>layer, mask</i>
     * @see MaskLayerController
     */
    static String Options_Keywords_LayerMask() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_LayerMask");
    }
    /**
     * @return <i>Quicklook</i>
     * @see QuicklookOptionsController
     */
    static String Options_Keywords_QuicklookOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_QuicklookOptions");
    }
    /**
     * @return <i>RGB, profile</i>
     * @see RgbController
     */
    static String Options_Keywords_RGB() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_RGB");
    }
    /**
     * @return <i>write, writing, save, header, MPH, SPH, history, annotation, incremental</i>
     * @see WriteOptionsController
     */
    static String Options_Keywords_WriteOptions() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "Options_Keywords_WriteOptions");
    }
    /**
     * @return <i>Geo-Location</i>
     * @see GeoLocationController
     */
    static String TXT_GeoLocationController_DisplayName() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "TXT_GeoLocationController_DisplayName");
    }
    /**
     * @return <i>geo, location, geo-location, compatibility, differ</i>
     * @see GeoLocationController
     */
    static String TXT_GeoLocationController_Keyword() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "TXT_GeoLocationController_Keyword");
    }
    private Bundle() {}
}
